==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/integration-tests/src/test/java/org/apache/druid/tests/indexer/AbstractKinesisIndexingServiceEmptyShardsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.tests.indexer;

import org.apache.druid.java.util.common.logger.Logger;
import org.apache.druid.testing.IntegrationTestingConfig;
import org.apache.druid.testing.utils.KinesisSingleShardEventWriter;
import org.apache.druid.testing.utils.StreamEventWriter;

import javax.annotation.Nullable;

public abstract class AbstractKinesisIndexingServiceEmptyShardsTest extends AbstractKinesisIndexingServiceTest
{
  private static final Logger LOG = new Logger(AbstractKinesisIndexingServiceEmptyShardsTest.class);

  @Override
  StreamEventWriter createStreamEventWriter(IntegrationTestingConfig config, @Nullable Boolean transactionEnabled)
      throws Exception
  {
    if (transactionEnabled != null) {
      LOG.warn(
          "Kinesis event writer doesn't support transaction. Ignoring the given parameter transactionEnabled[%s]",
          transactionEnabled
      );
    }
    return new KinesisSingleShardEventWriter(config.getStreamEndpoint(), false);
  }
}

==> apache-druid-35.0.0-src.tar.gz: apache-druid-35.0.0-src/integration-tests/src/test/java/org/apache/druid/tests/indexer/AbstractKinesisIndexingServiceEmptyShardsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.tests.indexer;

import org.apache.druid.java.util.common.logger.Logger;
import org.apache.druid.testing.tools.IntegrationTestingConfig;
import org.apache.druid.testing.tools.KinesisSingleShardEventWriter;
import org.apache.druid.testing.tools.StreamEventWriter;

import javax.annotation.Nullable;

public abstract class AbstractKinesisIndexingServiceEmptyShardsTest extends AbstractKinesisIndexingServiceTest
{
  private static final Logger LOG = new Logger(AbstractKinesisIndexingServiceEmptyShardsTest.class);

  @Override
  StreamEventWriter createStreamEventWriter(IntegrationTestingConfig config, @Nullable Boolean transactionEnabled)
      throws Exception
  {
    if (transactionEnabled != null) {
      LOG.warn(
          "Kinesis event writer doesn't support transaction. Ignoring the given parameter transactionEnabled[%s]",
          transactionEnabled
      );
    }
    return new KinesisSingleShardEventWriter(config.getStreamEndpoint(), false);
  }
}
